@@ -6,10 +6,10 @@ module Main(main) where
 
 #include "gtk2hs-config.h"
 
-import Char(showLitChar)
-import List(nub, partition)
-import Maybe(catMaybes)
-import System(getArgs, exitWith, ExitCode(..))
+import Data.Char   (showLitChar)
+import Data.List   (nub)
+import System.Environment (getArgs)
+import System.Exit (exitWith, ExitCode(..))
 
 -- Define all possible data types the GTK will supply in callbacks.
 --
@@ -328,8 +328,7 @@ marshExec Tptr	  n = indent 4.ss "let ptr".shows n.ss "' = castPtr ptr".
 marshExec Tobject n = indent 4.ss "objectRef obj".shows n.
 		      indent 4.ss "obj".shows n.
 		      ss "' <- liftM (fromGObject.mkGObject) $".
-		      indent 5.ss "newForeignPtr obj".shows n.
-		      ss " (objectUnref obj".shows n.sc ')'
+		      indent 5.ss "newForeignPtr obj".shows n.ss " objectUnref"
 marshExec _	  _ = id
 
 marshRet :: Types -> ShowS
@@ -431,7 +430,7 @@ usage = do
    "where\n"++
    "  <signatureFile> is gtkmarshal.list from the the source Gtk+ tree\n"++
    "  <templateFile>  the name and path of the Signal.chs.template file\n"++
-   "  <outFile>	      is the name and path of the output file.\n"++
+   "  <outFile>       is the name and path of the output file.\n"++
    "  <moduleName>    the module name for <outFile>\n"
  exitWith $ ExitFailure 1
 
